import { Identify } from './pb/message.js';
import type { IdentifyService, IdentifyServiceComponents, IdentifyServiceInit } from './index.js';
import type { IdentifyResult, AbortOptions } from '@libp2p/interface';
import type { Connection } from '@libp2p/interface/connection';
import type { Startable } from '@libp2p/interface/startable';
import type { IncomingStreamData } from '@libp2p/interface-internal/registrar';
export declare class DefaultIdentifyService implements Startable, IdentifyService {
    #private;
    private readonly identifyProtocolStr;
    private readonly identifyPushProtocolStr;
    readonly host: {
        protocolVersion: string;
        agentVersion: string;
    };
    private started;
    private readonly timeout;
    private readonly peerId;
    private readonly peerStore;
    private readonly registrar;
    private readonly connectionManager;
    private readonly addressManager;
    private readonly maxInboundStreams;
    private readonly maxOutboundStreams;
    private readonly maxPushIncomingStreams;
    private readonly maxPushOutgoingStreams;
    private readonly maxIdentifyMessageSize;
    private readonly maxObservedAddresses;
    private readonly events;
    private readonly runOnTransientConnection;
    constructor(components: IdentifyServiceComponents, init: IdentifyServiceInit);
    isStarted(): boolean;
    start(): Promise<void>;
    stop(): Promise<void>;
    /**
     * Send an Identify Push update to the list of connections
     */
    pushToConnections(connections: Connection[]): Promise<void>;
    /**
     * Calls `push` on all peer connections
     */
    push(): Promise<void>;
    _identify(connection: Connection, options?: AbortOptions): Promise<Identify>;
    identify(connection: Connection, options?: AbortOptions): Promise<IdentifyResult>;
    /**
     * Sends the `Identify` response with the Signed Peer Record
     * to the requesting peer over the given `connection`
     */
    _handleIdentify(data: IncomingStreamData): Promise<void>;
    /**
     * Reads the Identify Push message from the given `connection`
     */
    _handlePush(data: IncomingStreamData): Promise<void>;
}
//# sourceMappingURL=identify.d.ts.map